Stan Math Library: stan/math/prim/mat/fun/add.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
add.hpp File Reference
`#include <boost/math/tools/promotion.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_matching_dims.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R, C > | stan::math::add (const Eigen::Matrix< T1, R, C > &m1, const Eigen::Matrix< T2, R, C > &m2)
| Return the sum of the specified matrices. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R, C > | stan::math::add (const Eigen::Matrix< T1, R, C > &m, const T2 &c)
| Return the sum of the specified matrix and specified scalar. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R, C > | stan::math::add (const T1 &c, const Eigen::Matrix< T2, R, C > &m)
| Return the sum of the specified scalar and specified matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.